import React, { PureComponent } from 'react';
import { connect } from 'react-redux';
import { NavModel } from '@grafana/data';
import { ReportPage } from './ReportPage';
import Page from 'app/core/components/Page/Page';
import { createReport } from './state/actions';
import { getNavModel } from 'app/core/selectors/navModel';
import { StoreState } from 'app/types';
import { Report, SchedulingFrequency } from '../types';

interface Props {
  navModel: NavModel;
  createReport: typeof createReport;
}

export class NewReportPage extends PureComponent<Props> {
  emptyReport: Report = {
    id: 0,
    name: '',
    recipients: '',
    replyTo: '',
    message:
      'Hi all, \n' +
      'please find enclosed a PDF status report. If you have any questions, feel free to get in touch with me!\n' +
      'Have a great day. \n' +
      'Best,',
    dashboardId: undefined,
    dashboardName: '',
    schedule: {
      frequency: SchedulingFrequency.Weekly,
      hour: 12,
      minute: 0,
      day: 'monday',
    },
  };

  render() {
    const { createReport, navModel } = this.props;

    return (
      <Page navModel={navModel}>
        <Page.Contents isLoading={false}>
          <ReportPage heading="New report" createOrUpdate={createReport} report={this.emptyReport} />
        </Page.Contents>
      </Page>
    );
  }
}

function mapStateToProps(state: StoreState) {
  return {
    navModel: getNavModel(state.navIndex, 'reports-list'),
  };
}

const mapActionsToProps = {
  createReport,
};

export default connect(
  mapStateToProps,
  mapActionsToProps
)(NewReportPage);
